@@ -4,18 +4,18 @@
 
 __author__ = """SekouDiaoNlp"""
 __email__ = 'diao.sekou.nlp@gmail.com'
-__version__ = '1.2.7'
+__version__ = '1.3.0'
 __copyright__ = "Copyright (c) 2021, SekouDiaoNlp"
 __credits__ = ("Lexique383",)
 __license__ = "MIT"
 __maintainer__ = "SekouDiaoNlp"
 __status__ = "Production"
 
+__all__ = ['Lexique383', 'LexItem', 'LexEntryTypes']
+
 import pkg_resources
-try:
-    from .pylexique import Lexique383, LexItem
-except ModuleNotFoundError or ImportError:
-    from pylexique import Lexique383, LexItem
+
+from .pylexique import Lexique383, LexItem, LexEntryTypes
 
 _RESOURCE_PACKAGE = 'pylexique'
 _RESOURCE_PATH = pkg_resources.resource_filename(_RESOURCE_PACKAGE, 'Lexique383/Lexique383.txt')
